@@ -1,5 +1,5 @@
 /*
- * $Id: DefinitionsReader.java 652862 2008-05-02 18:22:56Z apetrelli $
+ * $Id: DefinitionsReader.java 829574 2009-10-25 14:15:31Z apetrelli $
  *
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -36,21 +36,10 @@ import org.apache.tiles.Definition;
  * not perform any internationalization duties or inheritance of Definitions.
  * It only reads from the source and returns a Map of objects read.</p>
  *
- * @version $Rev: 652862 $ $Date: 2008-05-02 20:22:56 +0200 (ven, 02 mag 2008) $
+ * @version $Rev: 829574 $ $Date: 2009-10-26 01:15:31 +1100 (Mon, 26 Oct 2009) $
  */
 public interface DefinitionsReader {
 
-    /**
-     * Initializes the <code>DefinitionsReader</code> object.
-     * <p/>
-     * This method must be called before the {@link #read(java.lang.Object)} method is called.
-     *
-     * @param params A map of properties used to set up the reader.
-     * @throws DefinitionsFactoryException if required properties are not
-     *                                     passed in or the initialization fails.
-     */
-    void init(Map<String, String> params);
-
     /**
      * Reads <code>{@link Definition}</code> objects from a source.
      * <p/>
